@@ -78,11 +78,6 @@ class Yaml_Config(object):
         return cls()
     
     def init_store(self):
-        from storm.locals import create_database
-        from torweb.db import CacheStore
-        from torweb.db import CacheQuery
-        from sqlalchemy import create_engine, MetaData
-        from sqlalchemy.orm import scoped_session, sessionmaker
         schemes = self.settings.get('schemes', {})
         for scheme in schemes:
             #if not hasattr(self.app, scheme.get('storm')):
@@ -101,34 +96,51 @@ class Yaml_Config(object):
                     % {'scheme': key,
                        'database_name': os.path.join(self.base_path, scheme.get('db', ''))
                       }
-
+            store = scheme.get("storm", None)
+            if store: self.init_storm(store, connection)
+            session = scheme.get("sqlalchemy", None)
+            if session: self.init_sqlalchemy(scheme, connection)
+    def init_storm(self, store, connection):
+        try:
+            import storm
+            from storm.locals import create_database
+            from torweb.db import CacheStore
             database = create_database(connection)
             cache_store = CacheStore(database)
-            setattr(self, scheme.get('storm', 'store'), cache_store)
-            setattr(self.app, scheme.get('storm', 'store'), cache_store)
-            if scheme.get('sqlalchemy', '') != '':
-                import _mysql_exceptions
-                from sqlalchemy import event
-                from sqlalchemy.exc import DisconnectionError
-                def my_on_checkout(dbapi_conn, connection_rec, connection_proxy):
-                    try:
-                        dbapi_conn.cursor().execute('select now()')
-                    except _mysql_exceptions.OperationalError:
-                        raise DisconnectionError
-                
-                engine = create_engine(
-                    connection,
-                    convert_unicode=True,
-                    encoding="utf-8",
-                    pool_recycle=3600*7,
-                    #echo_pool=True,
-                    echo=False,
-                )
-                event.listen(engine, 'checkout', my_on_checkout)
-                metadata = MetaData(bind=engine)
-                session = scoped_session(sessionmaker(bind=engine, query_cls=CacheQuery))
-                sqlalchemy_sessions = [session]
-                DB_Session = sessionmaker(bind=engine)
-                setattr(self.app, 'metadata', metadata)
-                setattr(self.app, scheme.get('sqlalchemy', 'session'), session)
-                setattr(self.app, 'sqlalchemy_sessions', sqlalchemy_sessions)
+            setattr(self, store, cache_store)
+            setattr(self.app, store, cache_store)
+        except Exception as e:
+            print e
+    def init_sqlalchemy(self, scheme, connection):
+        try:
+            import sqlalchemy
+            from sqlalchemy import create_engine, MetaData
+            from sqlalchemy.orm import scoped_session, sessionmaker
+            from torweb.db import CacheQuery
+            import _mysql_exceptions
+            from sqlalchemy import event
+            from sqlalchemy.exc import DisconnectionError
+            def my_on_checkout(dbapi_conn, connection_rec, connection_proxy):
+                try:
+                    dbapi_conn.cursor().execute('select now()')
+                except _mysql_exceptions.OperationalError:
+                    raise DisconnectionError
+            
+            engine = create_engine(
+                connection,
+                convert_unicode=True,
+                encoding="utf-8",
+                pool_recycle=3600*7,
+                #echo_pool=True,
+                echo=False,
+            )
+            event.listen(engine, 'checkout', my_on_checkout)
+            metadata = MetaData(bind=engine)
+            session = scoped_session(sessionmaker(bind=engine, query_cls=CacheQuery))
+            sqlalchemy_sessions = [session]
+            DB_Session = sessionmaker(bind=engine)
+            setattr(self.app, 'metadata', metadata)
+            setattr(self.app, scheme.get('sqlalchemy', 'session'), session)
+            setattr(self.app, 'sqlalchemy_sessions', sqlalchemy_sessions)
+        except Exception as e:
+            print e
